﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

using Arction.Wpf.Charting;
using Arction.Wpf.Charting.SeriesXY;
using Arction.Wpf.Charting.Views;
using Arction.Wpf.Charting.Views.ViewXY;
using Arction.Wpf.Charting.Axes; 


namespace WpfAppRealtimeScrolling
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        const int SeriesCount = 4;

        System.Windows.Threading.DispatcherTimer _timer;

        int _pointsAdded = 0;

        Random _rand = new Random(); 

        public MainWindow()
        {
            InitializeComponent();

            InitChart();

            _timer = new System.Windows.Threading.DispatcherTimer();
            _timer.Interval = TimeSpan.FromMilliseconds(10);
            _timer.Tick += _timer_Tick;
            _timer.Start(); 

        }

        private void _timer_Tick(object sender, EventArgs e)
        {
            chart1.BeginUpdate();

            double x = (double) _pointsAdded * 0.01;

            for (int i = 0; i < SeriesCount; i++)
            {
                SeriesPoint[] points = new SeriesPoint[1];
                points[0].X = x;
                points[0].Y = _rand.Next(-100, 100);
                chart1.ViewXY.PointLineSeries[i].AddPoints(points, false);
            }

            chart1.ViewXY.XAxes[0].ScrollPosition = x; 

            chart1.EndUpdate();

            _pointsAdded++; 
        }

        void InitChart()
        {
            chart1.BeginUpdate();

            ViewXY view = chart1.ViewXY;

            AxisX xAxis = view.XAxes[0];
            xAxis.SetRange(0, 20);
            xAxis.ScrollMode = XAxisScrollMode.Scrolling;

            view.YAxes.Clear();

            for (int seriesIndex = 0; seriesIndex < SeriesCount; seriesIndex++)
            {
                AxisY yAxis = new AxisY(view);
                yAxis.SetRange(-100, 100);
                view.YAxes.Add(yAxis);

                PointLineSeries line = new PointLineSeries(view, xAxis, yAxis);
                line.PointsVisible = false;
                line.LineStyle.Color = DefaultColors.SeriesForBlackBackgroundWpf[seriesIndex];
                view.PointLineSeries.Add(line); 
            }

            view.DropOldSeriesData = true; 

            view.AxisLayout.YAxesLayout = YAxesLayout.Stacked; 

            chart1.EndUpdate(); 
        }
    }
}
